/*
  CTYPES.H -- some platform-independent types

  Copyright  1997, Jim Mischel

  Modification History
  --------------------
  06/08/97 - jim - Initial coding
*/
#ifndef __CTYPES_H
#define __CTYPES_H

/*
  The definitions of BOOL, TRUE, FALSE, and NULL are identical to the way that
  <windows.h> defines them.  This eliminates any conflicts under Windows
  and DOS platforms.
*/
typedef int BOOL;

#ifndef FALSE
    #define FALSE   0
#endif

#ifndef TRUE
    #define TRUE    1
#endif

#ifndef NULL
    #if defined(__cplusplus) || defined(__WIN32__) || defined(__FLAT__)
        #define NULL    0
    #else
        #define NULL    ((void *)0)
    #endif
#endif

/*
  The platform-dependent types are:
    int32      // signed 32-bit integer
    uint32     // unsigned 32-bit integer
    int16      // signed 16-bit integer
    uint16     // unsigned 16-bit integer
    int8       // signed 8-bit integer
    uint8      // unsigned 8-bit integer
*/
#if defined(__WIN32__) || defined (__FLAT__)
    // 32-bit Windows and DOS platforms (tested with MSVC and BC++)
    typedef int            int32;
    typedef unsigned int   uint32;
    typedef short          int16;
    typedef unsigned short uint16;
    typedef char           int8;
    typedef unsigned char  uint8;
#else
    // 16-bit Windows and DOS platforms (tested with MSVC and BC++)
    typedef long           int32;
    typedef unsigned long  uint32;
    typedef int            int16;
    typedef unsigned int   uint16;
    typedef char           int8;
    typedef unsigned char  uint8;
#endif

// Miscellaneous types...
typedef unsigned int   uint;   // your basic unsigned int.  This is platform-dependent size!
typedef uint8          byte;   // everybody wants a byte...

#endif

