/*
  DIRSPAN.C
*/
#include <dos.h>
#include <dir.h>
#include "dirspan.h"

/*
  Process a file name argument.
  The argument passed may contain wildcards.  This function expands the passed
  file argument and calls ProcessFile for each file that matches the specification.

  If subdirectories are specified, then we scan those as well.
*/
void dirspanEnumFiles
    (
      char const          *Arg,
      BOOL const          DoSubdirs,
      dirspanEnumCallback Callback
    )
{
  char Filename[MAXPATH];
  char Drive[MAXDRIVE];
  char Dir[MAXDIR];
  char File[MAXFILE];
  char Ext[MAXEXT];

  struct ffblk ffblk;
  int done;

  fnsplit (Arg, Drive, Dir, File, Ext);

  // Do just files first....No subdirectories.
  done = findfirst (Arg, &ffblk, 0);
  while (!done)
  {
    // found a file.  Create a path with [Drive]:\[Dir]\filename.ext.
    // [Drive] and [Dir] we get from the passed argument.  The filename.ext
    // is taken from the ffblk.ff_name field returned by findfirst/findnext
    fnmerge (Filename, Drive, Dir, NULL, NULL);
    strcat (Filename, ffblk.ff_name);
    Callback (Filename);
    done = findnext (&ffblk);
  }

  if (DoSubdirs)
  {
    // search for subdirectories..
    fnmerge (Filename, Drive, Dir, "*", ".*");
    done = findfirst (Filename, &ffblk, FA_DIREC);
    while (!done)
    {
      // but we don't want the '.' or '..' directories.
      if ((ffblk.ff_attrib & FA_DIREC) &&
          (ffblk.ff_name[0] != '.'))
      {
        char tempDir[MAXDIR];
        char * c;

        // build new directory path name by taking existing directory path
        // and tacking on the subdirectory name.
        strcpy (tempDir, Dir);
        // add a backslash if necessary
        if (*tempDir != '\0')
        {
          c = &tempDir[strlen(tempDir)-1];
          if (*c != '\\')
          {
            *(c+1) = '\\';
            *(c+2) = '\0';
          }
        }
        // and then the subdirectory name
        strcat (tempDir, ffblk.ff_name);
        // put 'em all together and do a recursive call...
        fnmerge (Filename, Drive, tempDir, File, Ext);
        dirspanEnumFiles (Filename, DoSubdirs, Callback);
      }
      done = findnext (&ffblk);
    }
  }
}
